Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1098)

Unified Diff: chrome/browser/chromeos/login/managed/supervised_user_authentication.h

Issue 296773002: Add a Key class (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Rebased. Created 6 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/login/managed/supervised_user_authentication.h
diff --git a/chrome/browser/chromeos/login/managed/supervised_user_authentication.h b/chrome/browser/chromeos/login/managed/supervised_user_authentication.h
index 0a807326e0e5db09287e6564842adbba200bacaa..2ce5730270fd19fd9a80736baa8feac59c59311e 100644
--- a/chrome/browser/chromeos/login/managed/supervised_user_authentication.h
+++ b/chrome/browser/chromeos/login/managed/supervised_user_authentication.h
@@ -56,12 +56,8 @@ class SupervisedUserAuthentication {
// schema should be migrated somehow.
Schema GetStableSchema();
- // Transforms password according to schema specified in Local State.
- std::string TransformPassword(const std::string& supervised_user_id,
- const std::string& password);
-
- // Transforms password according to schema specified in Local State.
- UserContext TransformPasswordInContext(const UserContext& context);
+ // Transforms key according to schema specified in Local State.
+ UserContext TransformKey(const UserContext& context);
// Fills |password_data| with |password|-specific data for |user_id|,
// depending on target schema. Does not affect Local State.
@@ -105,10 +101,6 @@ class SupervisedUserAuthentication {
// Utility method that gets schema version for |user_id| from Local State.
Schema GetPasswordSchema(const std::string& user_id);
- static std::string BuildPasswordForHashWithSaltSchema(
- const std::string& salt,
- const std::string& plain_password);
-
static std::string BuildPasswordSignature(
const std::string& password,
int revision,

Powered by Google App Engine
This is Rietveld 408576698